[−][src]Enum assembler::mnemonic_parameter_types::registers::Register32Bit
Register 0 (EAX) is defined on this enumeration but optimal encodings of it in combination with mnemonics exist and should be preferred as they increase code density.
Registers 8 to 15 when encoded decrease code density (ie they are less efficiently encoded than registers 1 to 7).
Variants
EAXRegister 0.
ECXRegister 1.
The fourth function argument in the System V Application Binary Interface for x86-64.
EDXRegister 2.
The third function argument in the System V Application Binary Interface for x86-64.
EBXRegister 3.
ESPRegister 4.
EBPRegister 5.
ESIRegister 6.
The 'source' operand in string instructions.
The second function argument in the System V Application Binary Interface for x86-64.
EDIRegister 7.
The 'destination' operand in string instructions.
The first function argument in the System V Application Binary Interface for x86-64.
R8DRegister 8.
The fifth function argument in the System V Application Binary Interface for x86-64.
R9DRegister 9.
The sixth function argument in the System V Application Binary Interface for x86-64.
R10DRegister 10.
R11DRegister 11.
R12DRegister 12.
R13DRegister 13.
R14DRegister 14.
R15DRegister 15.