[][src]Enum assembler::mnemonic_parameter_types::registers::X87Register

#[repr(u8)]
pub enum X87Register { ST0, ST1, ST2, ST3, ST4, ST5, ST6, ST7, }

Register 0 (ST(0)) is defined on this enumeration but optimal encodings of it in combination with mnemonics exist and should be preferred as they increase code density.

Variants

ST0

Register ST(0).

ST1

Register ST(1).

ST2

Register ST(2).

ST3

Register ST(3).

ST4

Register ST(4).

ST5

Register ST(5).

ST6

Register ST(6).

ST7

Register ST(7).