[][src]Enum assembler::mnemonic_parameter_types::registers::XMMRegister

#[repr(u8)]
pub enum XMMRegister { XMM0, XMM1, XMM2, XMM3, XMM4, XMM5, XMM6, XMM7, XMM8, XMM9, XMM10, XMM11, XMM12, XMM13, XMM14, XMM15, }

Register 0 (XMM0) is defined on this enumeration but optimal encodings of it in combination with mnemonics exist and should be preferred as they increase code density.

Variants

XMM0

Register 0.

XMM1

Register 1.

XMM2

Register 2.

XMM3

Register 3.

XMM4

Register 7.

XMM5

Register 5.

XMM6

Register 6.

XMM7

Register 7.

XMM8

Register 8.

XMM9

Register 9.

XMM10

Register 10.

XMM11

Register 11.

XMM12

Register 12.

XMM13

Register 13.

XMM14

Register 14.

XMM15

Register 15.