[][src]Enum assembler::mnemonic_parameter_types::registers::Register64Bit

#[repr(u8)]
pub enum Register64Bit { RAX, RCX, RDX, RBX, RSP, RBP, RSI, RDI, R8, R9, R10, R11, R12, R13, R14, R15, }

Register 0 (RAX) is defined on this enumeration but optimal encodings of it in combination with mnemonics exist and should be preferred as they increase code density.

Registers 8 to 15 when encoded decrease code density (ie they are less efficiently encoded than registers 1 to 7).

Variants

RAX

Register 0.

RCX

Register 1.

The fourth function argument in the System V Application Binary Interface for x86-64.

RDX

Register 2.

The third function argument in the System V Application Binary Interface for x86-64.

RBX

Register 3.

RSP

Register 4.

RBP

Register 5.

RSI

Register 6.

The 'source' operand in string instructions.

The second function argument in the System V Application Binary Interface for x86-64.

RDI

Register 7.

The 'destination' operand in string instructions.

The first function argument in the System V Application Binary Interface for x86-64.

R8

Register 8.

The fifth function argument in the System V Application Binary Interface for x86-64.

R9

Register 9.

The sixth function argument in the System V Application Binary Interface for x86-64.

R10

Register 10.

R11

Register 11.

R12

Register 12.

R13

Register 13.

R14

Register 14.

R15

Register 15.