[−][src]Enum assembler::mnemonic_parameter_types::registers::X87Register
Register 0 (ST(0)) is defined on this enumeration but optimal encodings of it in combination with mnemonics exist and should be preferred as they increase code density.
Variants
ST0Register ST(0).
ST1Register ST(1).
ST2Register ST(2).
ST3Register ST(3).
ST4Register ST(4).
ST5Register ST(5).
ST6Register ST(6).
ST7Register ST(7).