[−][src]Enum assembler::mnemonic_parameter_types::registers::XMMRegister
Register 0 (XMM0) is defined on this enumeration but optimal encodings of it in combination with mnemonics exist and should be preferred as they increase code density.
Variants
XMM0Register 0.
XMM1Register 1.
XMM2Register 2.
XMM3Register 3.
XMM4Register 7.
XMM5Register 5.
XMM6Register 6.
XMM7Register 7.
XMM8Register 8.
XMM9Register 9.
XMM10Register 10.
XMM11Register 11.
XMM12Register 12.
XMM13Register 13.
XMM14Register 14.
XMM15Register 15.